"""
Created on Feb 19, 2018

@author: MCC
"""

from ctypes import c_longlong, byref
from .ul_enums import MemRegion, MemAccessType
from .ul_structs import MemDescriptor
from .ul_exception import ULException
from .mem_region_info import MemRegionInfo
from .ul_c_interface import lib, DevItemInfo
from .utils import enum_mask_to_list


class DevMemInfo:
    """
    Provides information about the reserved memory of the DAQ device.

    Args:
        handle: UL DAQ Device handle.
    """

    def __init__(self, handle):
        self.__handle = handle

    def get_mem_regions(self):
        # type: () -> list[MemRegion]
        """
        Gets a bitmask of memory regions.

        Returns:
            A list of supported :class:`MemRegion` objects.

        Raises:
            :class:`ULException`
        """
        memory_regions_mask = c_longlong()
        err = lib.ulDevGetInfo(self.__handle, DevItemInfo.MEM_REGIONS, 0, byref(memory_regions_mask))
        if err != 0:
            raise ULException(err)
        return enum_mask_to_list(MemRegion, memory_regions_mask.value)

    def get_mem_region_info(self, mem_region):
        # type: (MemRegion) -> MemRegionInfo
        """
        Gets memory region info objects which contain information about
        the specified region of memory.

        Returns:
            A :class:`MemRegionInfo` object.

        Raises:
            :class:`ULException`
        """
        mem_descriptor = MemDescriptor()
        err = lib.ulMemGetInfo(self.__handle, mem_region, byref(mem_descriptor))
        if err != 0:
            raise ULException(err)
        access_types_list = enum_mask_to_list(MemAccessType, mem_descriptor.access_types)

        mem_region_info = MemRegionInfo(mem_region, mem_descriptor.address, mem_descriptor.size,
                                        access_types_list)

        return mem_region_info
