"""
Created on Feb 19, 2018

@author: MCC
"""


class MemRegionInfo:
    """
    Information about a region of memory.

    Args:
        region_type: A :class:`MemRegion` value.
        address: The address of the memory region.
        size: The size of the memory region in bytes.
        access_type: A list of :class:`MemAccessType` values.
    """
    
    def __init__(self, region_type, address, size, access_types):
        self._region_type = region_type
        self._address = address
        self._size = size
        self._access_types = access_types

    def get_region_type(self):
        """
        Gets a bitmask of memory region types.

        Returns:
            A :class:`MemRegion` value.
        """
        return self._region_type

    def get_address(self):
        """
        Gets the address of the memory region.

        Returns:
            The address of the memory region.
        """
        return self._address

    def get_size(self):
        """
        Gets the size of the memory region.

        Returns:
            The size of the memory region in bytes.
        """
        return self._size

    def get_access_types(self):
        """
        Gets the access types of the memory region.

        Returns:
            A list of :class:`MemAccessType` values.
        """
        return self._access_types
